==> jc-1.4.0.tar.gz: javax/swing/JComponent__24AccessibleJComponent__24AccessibleFocusHandler.h <==
// public class javax.swing.JComponent$AccessibleJComponent$AccessibleFocusHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 98f7dc9489e04141 javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler_H_
#define _JC_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_FocusEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent__24AccessibleJComponent$object;

// Typedefs
typedef struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_refs	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_refs;
typedef struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_nonrefs	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_nonrefs;
typedef struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$refs	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$refs;
typedef struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$nonrefs	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$nonrefs;
typedef struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object;

typedef const struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vmethods	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vmethods;
typedef const struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtable	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtable;
typedef const struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtype	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtype;

// Constructors
extern void _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$method$_init$104b892162f07ea0(_jc_env *, struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object *, struct _jc_javax_swing_JComponent__24AccessibleJComponent$object *);

// Virtual methods
extern void _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$method$focusGained$2b0b3146a729e224(_jc_env *, struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *);
extern void _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$method$focusLost$b4af7a719a65818b(_jc_env *, struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$method_info$focusGained$2b0b3146a729e224;
extern _jc_method _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$method_info$focusLost$b4af7a719a65818b;

// Virtual methods structure
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vmethods {
	void	(*focusGained$2b0b3146a729e224)(_jc_env *, struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *);
	void	(*focusLost$b4af7a719a65818b)(_jc_env *, struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *);
};

// Vtable
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vmethods	javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler;
};

// Vtype
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_refs {
	struct _jc_javax_swing_JComponent__24AccessibleJComponent$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$refs {
    _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_refs	javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler;
};

// Object instance structure
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object {
	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtype	*vtype;
	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtype _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$class_object;

#endif	/* _JC_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JComponent__24AccessibleJComponent__24AccessibleFocusHandler.h <==
// public class javax.swing.JComponent$AccessibleJComponent$AccessibleFocusHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 98f7dc9489e04141 javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler_H_
#define _JC_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_FocusEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent__24AccessibleJComponent$object;

// Typedefs
typedef struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_refs	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_refs;
typedef struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_nonrefs	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_nonrefs;
typedef struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$refs	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$refs;
typedef struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$nonrefs	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$nonrefs;
typedef struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object;

typedef const struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vmethods	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vmethods;
typedef const struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtable	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtable;
typedef const struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtype	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtype;

// Constructors
extern void _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$method$_init$104b892162f07ea0(_jc_env *, struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object *, struct _jc_javax_swing_JComponent__24AccessibleJComponent$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$method$focusGained$2b0b3146a729e224(_jc_env *, struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$method$focusLost$b4af7a719a65818b(_jc_env *, struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$method_info$focusGained$2b0b3146a729e224;
extern _jc_method _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$method_info$focusLost$b4af7a719a65818b;

// Virtual methods structure
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vmethods {
	void	(*focusGained$2b0b3146a729e224)(_jc_env *, struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
	void	(*focusLost$b4af7a719a65818b)(_jc_env *, struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vmethods	javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler;
};

// Vtype
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_refs {
	struct _jc_javax_swing_JComponent__24AccessibleJComponent$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$refs {
    _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_refs	javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler;
};

// Object instance structure
struct _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$object {
	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtype	*vtype;
	_jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$vtype _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler$class_object;

#endif	/* _JC_javax_swing_JComponent__24AccessibleJComponent__24AccessibleFocusHandler_H_ */
